pub fn client_answer_data<T: DeserializeOwned>(
answer: &ClientToolAnswer,
) -> ChatbotResult<T>Expand description
The data a client answered with, as the tool’s own response shape.
pub fn client_answer_data<T: DeserializeOwned>(
answer: &ClientToolAnswer,
) -> ChatbotResult<T>The data a client answered with, as the tool’s own response shape.