call_chatbot_tool

Function call_chatbot_tool 

pub async fn call_chatbot_tool(
    conn: &mut PgConnection,
    fn_name: &str,
    fn_args: String,
    user_context: &ChatbotUserContext,
) -> ChatbotResult<ChatbotToolCallResult>
Call a chatbot tool with LLM-provided arguments by matching the tool call made by the LLM. User context and db connection are needed for some tools.